{% comment %}
Build for lookbook params editor to replace the default checkbox input
{% endcomment %}

<label for="{{ widget.attrs.id }}" class="inline-flex relative items-center cursor-pointer">
  <input type="checkbox"
         id="{{ widget.attrs.id }}"
         name="{{ widget.name }}"
         class="sr-only peer"
         {% include "django/forms/widgets/attrs.html" %}
  >
  <div class="w-11 h-6 bg-gray-200 rounded-full dark:bg-gray-700 peer-focus:outline-none peer-focus:ring-4 peer-focus:ring-blue-300 peer peer-checked:after:translate-x-full peer-checked:after:border-white after:content-[ dark:peer-focus:ring-blue-800''] after:absolute after:top-[2px] after:left-[2px] after:bg-white after:border-gray-300 after:border after:rounded-full after:h-5 after:w-5 after:transition-all dark:border-gray-600 peer-checked:bg-blue-600"></div>
</label>
