{% extends 'django_lookbook/base.html' %}

{% block content %}
  <div class="flex justify-center items-center h-full"
  >
    <div class="flex flex-col items-center">
      <h1 class="text-6xl font-bold">4😵4</h1>

      <h6 class="mb-2 text-2xl font-bold text-center text-gray-800 md:text-3xl">
        <span class="text-red-500">Oops!</span> Preview not found
      </h6>

    </div>
  </div>
{% endblock %}
